import React, { createElement, Component } from 'react';
import { create } from 'nano-css';
import { addon } from 'nano-css/addon/cache';
import { addon as addon$1 } from 'nano-css/addon/nesting';
import { addon as addon$2 } from 'nano-css/addon/rule';
import { addon as addon$3 } from 'nano-css/addon/unitless';
import { addon as addon$4 } from 'nano-css/addon/jsx';
import { addon as addon$5 } from 'nano-css/addon/emmet';

function _typeof(obj) {
  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

// Default Theme Object used by this module, Should be overriden and passed to components
// to update the theme...
// keeping the names similar to Emmet based CSS Keys, to keep things simple and memorable...
// Checkout [this](https://docs.emmet.io/cheat-sheet/) for details on supported keys...
// Most of the keys here are for review purpose, so that themes can be created by
var defaultTheme = {
  // Colors
  fadedWhite: '#FAFAFA',
  fadedBlack: '#424242',
  light: {
    primary: '#00897B',
    // Teal 600
    primaryFg: '#FAFAFA',
    // Grey 50
    secondary: '#FFB300',
    // Amber 600
    secondaryFg: '#212121',
    // Grey  900
    disabled: '#F5F5F5',
    // Grey 100
    disabledFg: '#E0E0E0' // Grey 300

  },
  fz: '16px',
  btn: {
    // If `bgc` and `c` are not passed, default Primary Color will be used...
    fz: 16,
    bdrs: 4
  }
};

var nano = create({
  pfx: 'kamamana-',
  h: createElement
}); // Add addons you would like to use.

addon(nano);
addon$1(nano);
addon$2(nano);
addon$3(nano);
addon$4(nano);
addon$5(nano); // Supports Emmet abbreviations

var rule = nano.rule,
    jsx = nano.jsx;

var Button = jsx('button', {
  d: 'flex',
  ai: 'center',
  bxz: 'border-box',
  bdrs: '2px',
  fz: '16px',
  lh: 1.4,
  m: '0 8px 15px 0',
  p: '8px 15px',
  cur: 'pointer',
  trs: 'all 0.3s ease-out',
  '&:focus': {
    ol: 'none'
  },
  '&[disabled], &.disabled': {
    cur: 'not-allowed',
    bgc: defaultTheme.light.disabled,
    c: defaultTheme.light.disabledFg,
    bd: "1px solid ".concat(defaultTheme.light.disabledFg)
  },
  '& .btn-icon': {
    mr: 8
  },
  '& .btn-text': {
    fz: '14px'
  },
  '& .btn-icon + .btn-text': {
    ml: '8px'
  }
}, 'ButtonStyled');

var Icon =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Icon, _React$Component);

  function Icon() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Icon);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Icon)).call.apply(_getPrototypeOf2, [this].concat(args)));
    _this.state = {
      module: null
    };
    return _this;
  }

  _createClass(Icon, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var _this2 = this;

      this.props.icon && import("./".concat(this.props.icon)).then(function (module) {
        _this2.setState({
          module: module.default
        });
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          icon = _this$props.icon,
          className = _this$props.className,
          rest = _objectWithoutProperties(_this$props, ["icon", "className"]);

      var Component$$1 = this.state.module;
      return Component$$1 ? React.createElement(Component$$1, _extends({
        className: className
      }, rest)) : null;
    }
  }]);

  return Icon;
}(React.Component);

/**
 * Returns and array of [r, g, b], else []
 * @param {string} rgbString RGB string of format rgb(r, g, b)
 */

var splitRGBfromRGBString = function splitRGBfromRGBString(rgbString) {
  var result = /^rgb\(\s*?(\d{1,3}),\s*(\d{1,3}),\s*(\d{1,3})\s*\)$/i.exec(rgbString);
  return result ? result.splice(1) : [];
};
var extractIntegerFromHexString = function extractIntegerFromHexString(hexString) {
  // Expand shorthand form (e.g. "03F") to full form (e.g. "0033FF")
  var shorthandRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i;

  var _hex = hexString && hexString.replace(shorthandRegex, function (m, r, g, b) {
    return "#".concat(r + r).concat(g + g).concat(b + b);
  });

  var result = _hex ? /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(_hex) : [];
  return result ? result.splice(1).map(function (val) {
    return parseInt(val, 16);
  }) : [];
};
var componentToHex = function componentToHex(c) {
  if (c / 255 < 0 || c / 255 > 1) {
    return null;
  }

  var hex = c.toString(16);
  return hex.length === 1 ? "0".concat(hex) : hex;
};
/**
 * Excepts a string of format `rgb(r, g, b)`
 * @param {string} rgb RGB CSS String to convert to Hex
 */

var rgbToHex = function rgbToHex(rgb) {
  var r, g, b;

  if (!rgb) {
    return null;
  }

  if (typeof rgb === 'string') {
    var _splitRGBfromRGBStrin = splitRGBfromRGBString(rgb).map(function (val) {
      return componentToHex(parseInt(val));
    });

    var _splitRGBfromRGBStrin2 = _slicedToArray(_splitRGBfromRGBStrin, 3);

    r = _splitRGBfromRGBStrin2[0];
    g = _splitRGBfromRGBStrin2[1];
    b = _splitRGBfromRGBStrin2[2];
  } else if (_typeof(rgb) === 'object' && rgb.hasOwnProperty('r')) {
    r = componentToHex(parseInt(rgb.r));
    g = componentToHex(parseInt(rgb.g));
    b = componentToHex(parseInt(rgb.b));
  }

  return r && g && b ? "#".concat(r).concat(g).concat(b) : null;
};
var hexToRgb = function hexToRgb(hex) {
  var _extractIntegerFromHe = extractIntegerFromHexString(hex),
      _extractIntegerFromHe2 = _slicedToArray(_extractIntegerFromHe, 3),
      r = _extractIntegerFromHe2[0],
      g = _extractIntegerFromHe2[1],
      b = _extractIntegerFromHe2[2];

  return !isNaN(r) && !isNaN(g) && !isNaN(b) ? {
    r: r,
    g: g,
    b: b
  } : null;
};
var getBoundedChangeAmount = function getBoundedChangeAmount() {
  var amount = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

  var _amount = amount < 0 ? 0 : amount > 100 ? 100 : amount;

  return _amount / 100 * 255;
};
/**
 * This method is not the efficient way for lightening the colors.. Will understand and figure things out later
 * v0.1 :P
 * It's easiest possible way to shade colors, help taken from https://stackoverflow.com/a/13542669/2849127
 */

var shader = function shader(color, amount) {
  if (color && color.hasOwnProperty('r') && color.hasOwnProperty('g') && color.hasOwnProperty('b')) {
    var r = color.r,
        g = color.g,
        b = color.b;
    r = r + amount;
    g = g + amount;
    b = b + amount;
    return {
      r: r > 255 ? 255 : r < 0 ? 0 : Math.round(r),
      g: g > 255 ? 255 : g < 0 ? 0 : Math.round(g),
      b: b > 255 ? 255 : b < 0 ? 0 : Math.round(b)
    };
  }

  return color;
}; // Wanted to use composition here, but not sure if it's possible with these functions??
var darken = function darken(color, amount) {
  return shader(color, -getBoundedChangeAmount(amount));
}; // Help taken from https://github.com/mapbox/react-colorpickr/blob/5c7d8498c539a99c1330a83b4c7d6a79b7daaff9/src/colorfunc.js#L6

var isDark = function isDark(color) {
  if (color) {
    var r = color.r,
        g = color.g,
        b = color.b;
    return !(r * 0.299 + g * 0.587 + b * 0.114 > 186);
  }

  return false;
};

var filterKeys = (function () {
  var obj = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  var definedKeys = Object.keys(obj).filter(function (key) {
    return !!key;
  });
  return definedKeys.reduce(function (filtered, key) {
    filtered[key] = obj[key];
    return filtered;
  }, {});
});

var Button$1 =
/*#__PURE__*/
function (_Component) {
  _inherits(Button$$1, _Component);

  _createClass(Button$$1, [{
    key: "filteredStyleProp",
    get: function get() {
      return filterKeys(this.props.style);
    }
  }, {
    key: "filteredBtnThemeProp",
    get: function get() {
      if (this.props.theme) {
        return filterKeys(this.props.theme.btn);
      }

      return {};
    }
  }, {
    key: "isGhostType",
    get: function get() {
      return this.props.type === 'ghost'; // Means Background is transparent, ALWAYS and Border animates
    }
  }, {
    key: "isBorderedType",
    get: function get() {
      return this.props.type === 'bordered'; // Means Background is white, Always, and Border animates
    } // Background related Colors...

  }, {
    key: "bgc",
    get: function get() {
      if (this.isGhostType) {
        return 'transparent';
      } else if (this.isBorderedType) {
        return defaultTheme.fadedWhite;
      }

      return this.state.theme.bgc;
    }
  }, {
    key: "bgHoverC",
    get: function get() {
      var defaultC = rgbToHex(darken(hexToRgb(this.state.theme.bgc), 10));

      if (this.isGhostType) {
        return 'transparent';
      } else if (this.isBorderedType) {
        return defaultTheme.fadedWhite;
      }

      return this.props.bgHoverC || (defaultC ? defaultC : defaultTheme.light.primary);
    } // Foreground related Colors...

  }, {
    key: "fgc",
    get: function get() {
      if (this.isGhostType) {
        return defaultTheme.fadedWhite;
      } else if (this.isBorderedType) {
        return defaultTheme.fadedBlack;
      }

      return this.state.theme.c || defaultTheme.fadedBlack;
    }
  }, {
    key: "fgHoverC",
    get: function get() {
      if (this.isGhostType || this.isBorderedType) {
        return this.props.fgHoverC || defaultTheme.light.primary;
      }

      return this.props.fgHoverC || (isDark(hexToRgb(this.bgHoverC)) ? defaultTheme.fadedWhite : defaultTheme.fadedBlack);
    } // Border related Colors...

  }, {
    key: "border",
    get: function get() {
      var bdc = this.state.theme.bdc || (this.state.theme.bgc ? this.state.theme.bgc : defaultTheme.light.primary);

      if (this.isGhostType || this.isBorderedType) {
        bdc = this.state.theme.bdc || this.fgc;
      }

      return "1px solid ".concat(bdc);
    }
  }, {
    key: "borderHoverC",
    get: function get() {
      var bdc = this.state.theme.bdc || this.bgHoverC;

      if (this.isGhostType || this.isBorderedType) {
        bdc = this.state.theme.bdc || this.fgHoverC;
      }

      return "1px solid ".concat(bdc);
    }
  }]);

  // Theme precedence... defaultTheme < props.theme < props.style
  function Button$$1(props) {
    var _this;

    _classCallCheck(this, Button$$1);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Button$$1).call(this, props));

    _this.getDefaultState = function () {
      return {
        fz: defaultTheme.btn.fz,
        c: defaultTheme.light.primaryFg,
        bgc: defaultTheme.light.primary
      };
    };

    var defaults = _this.getDefaultState();

    var filteredPropsStyle = _this.filteredStyleProp;
    var filteredPropsBtnTheme = _this.filteredBtnThemeProp;

    if (props.theme) {
      _this.state = {
        theme: _extends({}, defaults, filteredPropsBtnTheme, filteredPropsStyle)
      };
    } else {
      _this.state = {
        theme: _extends({}, defaults, filteredPropsStyle)
      };
    }

    return _this;
  }

  _createClass(Button$$1, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          theme = _this$props.theme,
          style = _this$props.style,
          bgHoverC = _this$props.bgHoverC,
          fgHoverC = _this$props.fgHoverC,
          type = _this$props.type,
          block = _this$props.block,
          text = _this$props.text,
          disabled = _this$props.disabled,
          icon = _this$props.icon,
          iconW = _this$props.iconW,
          iconH = _this$props.iconH,
          className = _this$props.className,
          rest = _objectWithoutProperties(_this$props, ["theme", "style", "bgHoverC", "fgHoverC", "type", "block", "text", "disabled", "icon", "iconW", "iconH", "className"]);

      var css = _extends({
        bgc: this.bgc,
        c: this.fgc,
        bd: this.border,
        '&:hover': {
          '&:not([disabled])': {
            bgc: this.bgHoverC,
            c: this.fgHoverC,
            bd: this.borderHoverC
          }
        }
      }, style);

      return React.createElement(Button, _extends({
        css: css,
        disabled: disabled,
        className: className
      }, rest), icon && React.createElement(Icon, {
        className: "btn-icon",
        icon: icon,
        w: iconW,
        h: iconH
      }), React.createElement("span", null, text));
    }
  }]);

  return Button$$1;
}(Component);

Button$1.defaultProps = {
  iconW: '16px',
  iconH: '16px'
};

var CardStyled = jsx('div', {
  bgc: defaultTheme.fadedWhite,
  bxz: 'border-box',
  bdrs: '2px',
  fz: '16px',
  lh: 1.4,
  p: '15px',
  bxsh: '0 0 15px -8px rgba(0,0,0,0.1), 0 2px 5px rgba(0,0,0,0.2)'
}, 'CardStyled');

var CardTitleStyled = jsx('div', {
  fz: 24,
  mb: 15
}, 'CardTitleStyled');

var CardTitle =
/*#__PURE__*/
function (_React$Component) {
  _inherits(CardTitle, _React$Component);

  function CardTitle() {
    _classCallCheck(this, CardTitle);

    return _possibleConstructorReturn(this, _getPrototypeOf(CardTitle).apply(this, arguments));
  }

  _createClass(CardTitle, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          style = _this$props.style;
      return React.createElement(CardTitleStyled, {
        css: style,
        className: className
      }, this.props.children);
    }
  }]);

  return CardTitle;
}(React.Component);

CardTitle.defaultProps = {
  className: 'title'
};

var CardContentStyled = jsx('div', {
  c: defaultTheme.fadedBlack
}, 'CardContentStyled');

var CardContent =
/*#__PURE__*/
function (_React$Component) {
  _inherits(CardContent, _React$Component);

  function CardContent() {
    _classCallCheck(this, CardContent);

    return _possibleConstructorReturn(this, _getPrototypeOf(CardContent).apply(this, arguments));
  }

  _createClass(CardContent, [{
    key: "render",
    value: function render() {
      var _this$props = this.props,
          className = _this$props.className,
          style = _this$props.style;
      return React.createElement(CardContentStyled, {
        css: style,
        className: className
      }, this.props.children);
    }
  }]);

  return CardContent;
}(React.Component);

CardContent.defaultProps = {
  className: 'content'
};

var Card =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(Card, _React$PureComponent);

  _createClass(Card, [{
    key: "Title",
    get: function get() {
      return this.props.title || this.state.title;
    }
  }, {
    key: "Content",
    get: function get() {
      return this.props.content || this.state.content;
    } // Helps in filtering <CardTitle /> Children into `title`, and all other unknown childrens
    // Wrapped with <CardContent /> or not, are filtered into `content`.
    // User should eaither use <CardContent /> explicitly for each children as a wrapper, or should
    // not use at all. If not sone so, unexpected results might come.

  }]);

  function Card(props) {
    var _this;

    _classCallCheck(this, Card);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Card).call(this, props));

    _this.getAcceptedChildren = function (_ref) {
      var children = _ref.children;
      var childArray = React.Children.toArray(children);
      var acceptedChilds = childArray.reduce(function (acceptedChilds, child) {
        if (child.type === CardTitle) {
          acceptedChilds.title = child;
          return acceptedChilds;
        } else if (child.type === CardContent) {
          acceptedChilds.content = child;
        } // accept everything else as Content Type, this will happen only if <CardContent /> is now explicitly set
        // as a child to <Card />


        acceptedChilds.contentWithoutType.push(child);
        return acceptedChilds;
      }, {
        title: null,
        content: undefined,
        contentWithoutType: []
      });

      if (!acceptedChilds.content) {
        acceptedChilds.content = React.createElement(CardContent, null, acceptedChilds.contentWithoutType);
      }

      return {
        title: acceptedChilds.title,
        content: acceptedChilds.content
      };
    };

    var _acceptedChilds = _this.getAcceptedChildren(props);

    _this.state = {
      title: _acceptedChilds.title,
      content: _acceptedChilds.content
    };
    return _this;
  }

  _createClass(Card, [{
    key: "render",
    value: function render() {
      return React.createElement(CardStyled, {
        css: this.props.style
      }, this.Title && // Pass default color/bgc styles to child, if parent has something different from default...
      React.cloneElement(this.Title, {
        style: _extends({
          c: this.props.style.c,
          bgc: this.props.style.bgc
        }, this.Title.props.style)
      }, this.Title.props.children), this.Content && React.cloneElement(this.Content, {
        style: _extends({
          c: this.props.style.c,
          bgc: this.props.style.bgc
        }, this.Content.props.style)
      }, this.Content.props.children));
    }
  }]);

  return Card;
}(React.PureComponent);

Card.defaultProps = {
  style: {
    c: defaultTheme.fadedBlack,
    bgc: defaultTheme.fadedWhite
  }
};

var Container = jsx('div', {
  d: 'flex'
}, 'FlexContainer');

var FlexItem = jsx('div', {
  fxg: 1,
  fxs: 1
}, 'FlexItem');

var Flexbox =
/*#__PURE__*/
function (_React$PureComponent) {
  _inherits(Flexbox, _React$PureComponent);

  function Flexbox(_props) {
    var _this;

    _classCallCheck(this, Flexbox);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Flexbox).call(this, _props));

    _this.prefix = function (props, colSpanList) {
      var childCount = React.Children.count(props.children);
      var total, colCount;

      if (colSpanList) {
        total = colSpanList.reduce(function (sum, n) {
          return sum + n;
        }, 0);
        colCount = colSpanList.length;
      } else {
        colCount = childCount;
      }

      if (colCount === childCount) {
        return React.Children.map(props.children, function (child, i) {
          if (child.type === Flexbox) {
            return child;
          }

          var width = colSpanList ? colSpanList[i] * 100 / total : 100;

          if (child.type === FlexItem) {
            return React.cloneElement(child, {
              css: _extends({}, child.props.style, {
                fxb: "".concat(width, "%")
              })
            }, child.props.children);
          }

          var _child$props = child.props,
              itemStyle = _child$props.itemStyle,
              rest = _objectWithoutProperties(_child$props, ["itemStyle"]);

          return React.createElement(FlexItem, {
            css: _extends({}, itemStyle, {
              fxb: "".concat(width, "%")
            })
          }, React.cloneElement(child, _extends({}, rest), child.props.children));
        });
      }

      throw new Error('Child Count must be equal to Column Count');
    };

    var _colSpanList = _props.cols ? _props.cols.split(':').map(function (num) {
      return parseInt(num, 10);
    }) : null;

    _this.state = {
      // Surround each Child with FlexItem for proper, width calculations...
      children: _this.prefix(_props, _colSpanList),
      colSpanList: _colSpanList
    };
    return _this;
  } // This method helps in wrapping flex items inside <FlexItemStyled /> if already not inside it.
  // Helps in removing extra code for <FlexItemStyled /> Wrappers...


  _createClass(Flexbox, [{
    key: "render",
    value: function render() {
      var css = _extends({}, this.props.style);

      return React.createElement(Container, {
        css: css
      }, this.state.children);
    }
  }]);

  return Flexbox;
}(React.PureComponent);

Flexbox.defaultProps = {
  style: {
    fxd: 'row'
  }
};

export { Button$1 as Button, Card, CardTitle, CardContent, Flexbox, FlexItem, nano, rule, jsx };
